@@ -24,6 +24,8 @@
 
 """Common definitions for the confget configuration parsing library."""
 
+import sys
+
 try:
     from typing import Dict, List, Optional  # noqa: H301
 
@@ -34,8 +36,17 @@ except ImportError:
     pass
 
 
-VERSION_STRING = "4.0.1"
-FEATURES = [("BASE", VERSION_STRING)]
+VERSION_STRING = "4.1.0"
+FEATURES = [
+    ("BASE", VERSION_STRING),
+    ("REGEX", "1.0"),
+    (
+        "REGEX_IMPL_PYTHON",
+        "{major}.{minor}".format(
+            major=sys.version_info[0], minor=sys.version_info[1]
+        ),
+    ),
+]
 
 
 class Config(object):
